@@ -55,13 +55,14 @@ For to encode unicode strings to other codecs the functions
 import getpass
 import os
 import platform
+import socket
 import sys
 import unicodedata
 
 from typing import Any, AnyStr, Dict, List, Optional, Tuple, Union, cast
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
 DATE_ISO: str = '%Y-%m-%d'                      #: ISO string format for date values (e.g. in config files/variables)
@@ -285,6 +286,35 @@ def sys_host_name() -> str:
     return platform.node()
 
 
+def sys_local_ip() -> str:
+    """ determine ip address of this system/machine in the local network (LAN or WLAN).
+
+    inspired by answers of SO users @dml and @fatal_error to the question: https://stackoverflow.com/questions/166506.
+
+    :return:                    ip address of this machine in the local network (WLAN or LAN/ethernet)
+                                or empty string if this machine is not connected to any network.
+    """
+    socket1 = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    try:
+        socket1.connect(('10.255.255.255', 1))      # doesn't even have to be reachable
+        ip_address = socket1.getsockname()[0]
+    except (OSError, IOError):                      # pragma: no cover
+        # ConnectionAbortedError, ConnectionError, ConnectionRefusedError, ConnectionResetError inherit from OSError
+        socket2 = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        try:
+            socket2.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
+            socket2.connect(('<broadcast>', 0))
+            ip_address = socket2.getsockname()[0]
+        except (OSError, IOError):
+            ip_address = ""
+        finally:
+            socket2.close()
+    finally:
+        socket1.close()
+
+    return ip_address
+
+
 def sys_platform() -> str:
     """ determine the operating system where this code is running.
 
